#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-server
version:              0.1.0.11
visibility:           public
id:                   pandoc-server-0.1.0.11-IgkzZS5IuO32jV8cJiIUoN
key:                  pandoc-server-0.1.0.11-IgkzZS5IuO32jV8cJiIUoN
license:              GPL-2.0-or-later
copyright:            (c) 2006-2024 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             https://pandoc.org
synopsis:             Pandoc document conversion as an HTTP servant-server
description:
    Pandoc-server provides pandoc'\''s document conversion functions
    in an HTTP server.

category:             Text
abi:                  459bbf51eda9a077a870ab2fd72da6f4
exposed:              True
exposed-modules:      Text.Pandoc.Server
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pandoc-server-0.1.0.11
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pandoc-server-0.1.0.11
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pandoc-server-0.1.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-server
hs-libraries:         HSpandoc-server-0.1.0.11-IgkzZS5IuO32jV8cJiIUoN
depends:
    aeson-2.2.2.0-3pjCpj5XtaHAHmzSwnt06z base-4.18.2.1
    base64-bytestring-1.2.1.0-LZzfJtlIG52AkUlWG0qoMe
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    doctemplates-0.11.0.1-JVCRff9KELenKRjYBPBwO
    pandoc-3.6.1-4I9KiJNjJgtBDfs2ZGE5fT
    pandoc-types-1.23.1.2-7r04FP2c39lATDnNYvBdb6
    servant-server-0.20.3.0-16cjsILEHa2LnOoK5WYYX8
    skylighting-0.14.5-Dx04r6CAlWS7nKy0YzdUv7 text-2.0.2
    unicode-collation-0.1.3.7-LhXsilLJD1s5mw4IHIf3B3
    wai-3.2.5-EjZd7LhAo0l7gnL0GV2ALc
    wai-cors-0.2.7-2It2WoJHeIMCLTy0DEMcgT

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-server/html/pandoc-server.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

